@@ -1,6 +1,6 @@
 package Image::Magick;
 
-#  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization
+#  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
 #  dedicated to making software imaging solutions freely available.
 #
 #  You may not use this file except in compliance with the License.  You may
@@ -16,6 +16,7 @@ package Image::Magick;
 #
 #  Initial version, written by Kyle Shorter.
 
+
 use strict;
 use Carp;
 use vars qw($VERSION @ISA @EXPORT $AUTOLOAD);
@@ -43,7 +44,7 @@ require AutoLoader;
       ConfigureError FatalErrorException
     );
 
-$VERSION = '6.9.13';
+$VERSION = '7.0.11';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -102,7 +103,7 @@ __END__
 
 =head1 NAME
 
-Image::Magick - objected-oriented Perl interface to ImageMagick. Use it to create, edit, compose, or convert bitmap images from within a Perl script.
+Image::Magick - objected-oriented Perl interface to ImageMagick. Use it to read, manipulate, or write an image or image sequence from within a Perl script.
 
 =head1 SYNOPSIS
 
@@ -121,11 +122,14 @@ This Perl extension allows the reading, manipulation and writing of
 a large number of image file formats using the ImageMagick library.
 It was originally developed to be used by CGI scripts for Web pages.
 
-   https://legacy.imagemagick.org/script/perl-magick.php
+A web page has been set up for this extension. See:
+
+	 file:///usr/local/share/doc/ImageMagick-7/www/perl-magick.html
+	 https://imagemagick.org/script/perl-magick.php
 
 If you have problems, go to
 
-   https://github.com/ImageMagick/ImageMagick6/issues
+   https://github.com/ImageMagick/ImageMagick/issue
 
 =head1 AUTHOR
 
